@@ -9,16 +9,16 @@ from .patterns import (
     query_name_definition_pattern,
     valid_query_name_pattern,
 )
-from .types import QueryDatum, QueryDataTree, SQLOperationType
+from .types import QueryDatum, QueryDataTree, SQLOperationType, DriverAdapterProtocol
 
 
 class QueryLoader:
-    def __init__(self, driver_adapter, record_classes: Optional[Dict]):
+    def __init__(self, driver_adapter: DriverAdapterProtocol, record_classes: Optional[Dict]):
         self.driver_adapter = driver_adapter
         self.record_classes = record_classes if record_classes is not None else {}
 
     def _make_query_datum(self, query_str: str):
-        lines = [l.strip() for l in query_str.strip().splitlines()]
+        lines = [line.strip() for line in query_str.strip().splitlines()]
         query_name = lines[0].replace("-", "_")
 
         if query_name.endswith("<!"):
@@ -45,6 +45,7 @@ class QueryLoader:
             )
 
         record_class_match = query_record_class_definition_pattern.match(lines[1])
+        record_class_name: Optional[str]
         if record_class_match:
             line_offset = 2
             record_class_name = record_class_match.group(1)
